@@ -1,6 +1,7 @@
 import abc
 
 import pandas as pd
+from .io import InsightData
 
 
 class InsightGenerator(metaclass=abc.ABCMeta):
@@ -34,8 +35,8 @@ class InsightGenerator(metaclass=abc.ABCMeta):
         raise NotImplementedError
 
     @abc.abstractmethod
-    def transform(self):
+    def transform(self, data: pd.DataFrame) -> InsightData:
         raise NotImplementedError
 
-    def provide_evidence(self):
+    def provide_evidence(self) -> str:
         pass
