@@ -16,6 +16,7 @@ class InsightData:
     tags: List[str]
     significance: float
     data: dict
+    categories: List[str]
 
 
 class _InsightDataEncoder(json.JSONEncoder):
@@ -24,7 +25,9 @@ class _InsightDataEncoder(json.JSONEncoder):
         if isinstance(obj, InsightData):
             return {"Payload": obj.data,
                     "Significance": obj.significance,
-                    "Tags": obj.tags}
+                    "Tags": obj.tags,
+                    "Categories": obj.categories
+                    }
         return json.JSONEncoder.default(self, obj)
 
 
